/**
 * Copyright (C) 2020 Wasabeef
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

/**
 * See about document.execCommand: https://developer.mozilla.org/en-US/docs/Web/API/Document/execCommand
 */

var RE = {};

RE.currentSelection = {
    "startContainer": 0,
    "startOffset": 0,
    "endContainer": 0,
    "endOffset": 0};

RE.editor = document.getElementById('editor');

document.addEventListener("selectionchange", function() { RE.backuprange(); });

// Initializations
RE.callback = function() {
    window.location.href = "re-callback://" + encodeURIComponent(RE.getHtml());
}

RE.setHtml = function(contents) {
    RE.editor.innerHTML = decodeURIComponent(contents.replace(/\+/g, '%20'));
}

RE.getHtml = function() {
    return RE.editor.innerHTML;
}

RE.getText = function() {
    return RE.editor.innerText;
}

RE.setBaseTextColor = function(color) {
    RE.editor.style.color  = color;
}

RE.setBaseFontSize = function(size) {
    RE.editor.style.fontSize = size;
}

RE.setPadding = function(left, top, right, bottom) {
  RE.editor.style.paddingLeft = left;
  RE.editor.style.paddingTop = top;
  RE.editor.style.paddingRight = right;
  RE.editor.style.paddingBottom = bottom;
}

RE.setBackgroundColor = function(color) {
    document.body.style.backgroundColor = color;
}

RE.setBackgroundImage = function(image) {
    RE.editor.style.backgroundImage = image;
}

RE.setWidth = function(size) {
    RE.editor.style.minWidth = size;
}

RE.setHeight = function(size) {
    RE.editor.style.height = size;
}

RE.setTextAlign = function(align) {
    RE.editor.style.textAlign = align;
}

RE.setVerticalAlign = function(align) {
    RE.editor.style.verticalAlign = align;
}

RE.setPlaceholder = function(placeholder) {
    RE.editor.setAttribute("placeholder", placeholder);
}

RE.setInputEnabled = function(inputEnabled) {
    RE.editor.contentEditable = String(inputEnabled);
}

RE.undo = function() {
    document.execCommand('undo', false, null);
}

RE.redo = function() {
    document.execCommand('redo', false, null);
}

RE.setBold = function() {
    document.execCommand('bold', false, null);
}

RE.setItalic = function() {
    document.execCommand('italic', false, null);
}

RE.setSubscript = function() {
    document.execCommand('subscript', false, null);
}

RE.setSuperscript = function() {
    document.execCommand('superscript', false, null);
}

RE.setStrikeThrough = function() {
    document.execCommand('strikeThrough', false, null);
}

RE.setUnderline = function() {
    document.execCommand('underline', false, null);
}

RE.setBullets = function() {
    document.execCommand('insertUnorderedList', false, null);
}

RE.setNumbers = function() {
    document.execCommand('insertOrderedList', false, null);
}

RE.setTextColor = function(color) {
    RE.restorerange();
//    var html = '<span style="color:'+color+'"></span>';
//    RE.insertHTML(html);
    document.execCommand("styleWithCSS", null, true);
    document.execCommand('foreColor', false, color);
    document.execCommand("styleWithCSS", null, false);
}

RE.setTextBackgroundColor = function(color) {
    RE.restorerange();
    document.execCommand("styleWithCSS", null, true);
    document.execCommand('hiliteColor', false, color);
    document.execCommand("styleWithCSS", null, false);
}

RE.setFontSize = function(fontSize){
    document.execCommand("fontSize", false, fontSize);
}

RE.setHeading = function(heading) {
    document.execCommand('formatBlock', false, '<h'+heading+'>');
}

RE.setIndent = function() {
    document.execCommand('indent', false, null);
}

RE.setOutdent = function() {
    document.execCommand('outdent', false, null);
}

RE.setJustifyLeft = function() {
    document.execCommand('justifyLeft', false, null);
}

RE.setJustifyCenter = function() {
    document.execCommand('justifyCenter', false, null);
}

RE.setJustifyRight = function() {
    document.execCommand('justifyRight', false, null);
}

RE.setBlockquote = function() {
    document.execCommand('formatBlock', false, '<blockquote>');
//    if(b)
//    document.execCommand('formatBlock', false, '<blockquote>');
//    else
//    document.execCommand('formatBlock', false, '<p>');
}

RE.insertVote = function(voteInfo,voteFormObj) {

  let voteForm = JSON.parse(voteInfo)
  let selectItem = ""

  if(voteForm.imageVoteOptionList == undefined){
      if(voteForm.numberOfOptions == 1){
         //TODO 单选
         for (let i = 0; i < voteForm.textVoteOptionList.length; i++) {
             if(i == 0){
                 selectItem += '<label style="display:block;display: flex;align-items: center;justify-content: space-between;background-color: #fff;padding:10px 20px;border-radius: 6px;margin-top: 6px;" for="'+voteForm.textVoteOptionList[i].option+'"><span>'+voteForm.textVoteOptionList[i].option+'</span><input checked type="radio" style="margin:0" id="'+voteForm.textVoteOptionList[i].option+'" name ="fruit" value="'+voteForm.textVoteOptionList[i].option+'" onclick="selectChange('+voteForm.textVoteOptionList[i].option+')"></label>'
              }else{
                 selectItem += '<label style="display:block;display: flex;align-items: center;justify-content: space-between;background-color: #fff;padding:10px 20px;border-radius: 6px;margin-top: 6px;" for="'+voteForm.textVoteOptionList[i].option+'"><span>'+voteForm.textVoteOptionList[i].option+'</span><input type="radio" style="margin:0" id="'+voteForm.textVoteOptionList[i].option+'" name ="fruit" value="'+voteForm.textVoteOptionList[i].option+'" onclick="selectChange('+voteForm.textVoteOptionList[i].option+')"></label>'
              }
         }
      }else{
      //TODO 多选
        for (let i = 0; i < voteForm.textVoteOptionList.length; i++) {
              if(i == 0){
                   selectItem += '<label style="display:block;display: flex;align-items: center;justify-content: space-between;background-color: #fff;padding:10px 20px;border-radius: 6px;margin-top: 6px;" for="'+voteForm.textVoteOptionList[i].option+'"><span>'+voteForm.textVoteOptionList[i].option+'</span><input checked type="checkbox" style="margin:0" id="'+voteForm.textVoteOptionList[i].option+'" name ="fruit" value="'+voteForm.textVoteOptionList[i].option+'" onclick="selectChange('+voteForm.textVoteOptionList[i].option+')"></label>'
               } else{
                   selectItem += '<label style="display:block;display: flex;align-items: center;justify-content: space-between;background-color: #fff;padding:10px 20px;border-radius: 6px;margin-top: 6px;" for="'+voteForm.textVoteOptionList[i].option+'"><span>'+voteForm.textVoteOptionList[i].option+'</span><input type="checkbox" style="margin:0" id="'+voteForm.textVoteOptionList[i].option+'" name ="fruit" value="'+voteForm.textVoteOptionList[i].option+'" onclick="selectChange('+voteForm.textVoteOptionList[i].option+')"></label>'
              }
         }

      }
  } else {
        if(voteForm.numberOfOptions == 1){
           //TODO 单选
            for (let i = 0; i < voteForm.imageVoteOptionList.length; i++) {
                if(i == 0){
                    selectItem += '<label style="display:block;display: flex;align-items: center;justify-content: space-between;background-color: #fff;padding:10px 20px;border-radius: 6px;margin-top: 6px;" for="'+voteForm.imageVoteOptionList[i].option+'"><div style="display: flex;align-items: center;"><img src="'+voteForm.imageVoteOptionList[i].pictureUrl+'" style="width: 50px;height: 50px;margin-right:20px" alt=""><span>'+voteForm.imageVoteOptionList[i].option+'</span></div><input type="radio" checked style="margin:0" id="'+voteForm.imageVoteOptionList[i].option+'" name ="fruit" value="'+voteForm.imageVoteOptionList[i].option+'" onclick="selectChange('+voteForm.imageVoteOptionList[i].option+')"></label>'
                } else {
                    selectItem += '<label style="display:block;display: flex;align-items: center;justify-content: space-between;background-color: #fff;padding:10px 20px;border-radius: 6px;margin-top: 6px;" for="'+voteForm.imageVoteOptionList[i].option+'"><div style="display: flex;align-items: center;"><img src="'+voteForm.imageVoteOptionList[i].pictureUrl+'" style="width: 50px;height: 50px;margin-right:20px" alt=""><span>'+voteForm.imageVoteOptionList[i].option+'</span></div><input type="radio" style="margin:0" id="'+voteForm.imageVoteOptionList[i].option+'" name ="fruit" value="'+voteForm.imageVoteOptionList[i].option+'" onclick="selectChange('+voteForm.imageVoteOptionList[i].option+')"></label>'
                }
            }
        }else{
        //TODO 多选
           for (let i = 0; i < voteForm.imageVoteOptionList.length; i++) {
               if(i == 0){
                  selectItem += '<label style="display:block;display: flex;align-items: center;justify-content: space-between;background-color: #fff;padding:10px 20px;border-radius: 6px;margin-top: 6px;" for="'+voteForm.imageVoteOptionList[i].option+'"><div style="display: flex;align-items: center;"><img src="'+voteForm.imageVoteOptionList[i].pictureUrl+'" style="width: 50px;height: 50px;margin-right:20px" alt=""><span>'+voteForm.imageVoteOptionList[i].option+'</span></div><input type="checkbox" checked style="margin:0" id="'+voteForm.imageVoteOptionList[i].option+'" name ="fruit" value="'+voteForm.imageVoteOptionList[i].option+'" onclick="selectChange('+voteForm.imageVoteOptionList[i].option+')"></label>'
               } else {
                  selectItem += '<label style="display:block;display: flex;align-items: center;justify-content: space-between;background-color: #fff;padding:10px 20px;border-radius: 6px;margin-top: 6px;" for="'+voteForm.imageVoteOptionList[i].option+'"><div style="display: flex;align-items: center;"><img src="'+voteForm.imageVoteOptionList[i].pictureUrl+'" style="width: 50px;height: 50px;margin-right:20px" alt=""><span>'+voteForm.imageVoteOptionList[i].option+'</span></div><input type="checkbox" style="margin:0" id="'+voteForm.imageVoteOptionList[i].option+'" name ="fruit" value="'+voteForm.imageVoteOptionList[i].option+'" onclick="selectChange('+voteForm.imageVoteOptionList[i].option+')"></label>'
               }
             }
        }
  }
  var html = '</br><div  onselectstart="return false" contenteditable="false" class="vote-container" style="background-color: #ececec;width:80%;padding:20px;margin: 20px auto;padding-bottom:1px;border-radius: 6px;font-size: 14px;position:relative;">'+
                            '<div onclick="document.getElementsByClassName(`vote-container`)[0].parentNode.removeChild(document.getElementsByClassName(`vote-container`)[0])" style="width:20px;height: 20px;display:flex;align-items:center;justify-content:center;border-radius: 50%;cursor: pointer;background-color: rgba(0, 0, 0, 0.5);position: absolute;top: -10px;right: -8px;"><svg t="1669451861074" class="icon" viewBox="0 0 1024 1024" version="1.1" xmlns="http://www.w3.org/2000/svg" p-id="3496" width="12" height="12"><path d="M584.127 514.61L910.316 840.8c20.01 20.01 20.082 52.467 0 72.549-20.011 20.011-52.468 20.082-72.55 0L511.579 587.16 185.39 913.348c-20.011 20.011-52.467 20.082-72.55 0-20.01-20.011-20.081-52.467 0-72.55L439.1 514.54 112.91 188.35c-20.01-20.01-20.081-52.467 0-72.549 20.012-20.01 52.468-20.082 72.55 0l326.188 326.189 326.188-326.189c20.011-20.01 52.468-20.082 72.55 0 20.01 20.011 20.081 52.468 0 72.55L584.126 514.61z" fill="#ffffff" p-id="3497"></path></svg></div>'+
                          '     <div  style="margin-bottom:10px" class="title">'+voteForm.title+'（'+voteForm.numberOfOptionsText+'）</div>'+
                           '     <div>'+
                                    selectItem+
                                      ' <div class="proportion" style="position: relative;display: flex;padding:10px 20px;background-color: #fff;border-radius: 6px;margin-top: 10px;justify-content: space-between;">'+
                                             '     <div class="proportion-left" style="z-index: 999;">中医 <span style="color: #429CE3;">30%</span></div>'+
                                             '     <div class="proportion-right" style="z-index: 999;">987</div>'+
                                             '     <div class="progress-bar" style="background-color: #c7e8ff;position: absolute;top: 0;left: 0;width: 30%;height: 100%;border-top-left-radius: 6px;border-bottom-left-radius: 6px;"></div>'+
                                             ' </div>
                                             ' <div class="proportion" style="position: relative;display: flex;padding:10px 20px;background-color: #fff;border-radius: 6px;margin-top: 10px;justify-content: space-between;">'+
                                             '     <div class="proportion-left" style="z-index: 999;">西医 <span style="color: #429CE3;">50%</span></div>'+
                                             '     <div class="proportion-right" style="z-index: 999;">987</div>'+
                                             '     <div class="progress-bar" style="background-color: #c7e8ff;position: absolute;top: 0;left: 0;width: 50%;height: 100%;border-top-left-radius: 6px;border-bottom-left-radius: 6px;"></div>'+
                                             ' </div>'+
                                             ' <div class="proportion" style="position: relative;display: flex;padding:10px 20px;background-color: #fff;border-radius: 6px;margin-top: 10px;justify-content: space-between;">'+
                                             '     <div class="proportion-left" style="z-index: 999;">中西医 <span style="color: #429CE3;">95%</span></div>'+
                                             '     <div class="proportion-right" style="z-index: 999;">987</div>'+
                                             '     <div class="progress-bar" style="background-color: #c7e8ff;position: absolute;top: 0;left: 0;width: 95%;height: 100%;border-top-left-radius: 6px;border-bottom-left-radius: 6px;"></div>'+
                                             ' </div>'+
                           '     </div>'+
                            '<div class="msg"  style="font-size: 12px;color: transparent;text-align: center;margin-top: 6px;">提示</div>'+
                           '     <div  style="background-color: #409de6;color: #fff;padding: 10px 0;border-radius: 6px;text-align: center;margin-top: 10px;" onclick="vote()">投票</div>'+
                           '     <div  style="margin-top: 20px;text-align: center;">投票截止时间：<span class="time">'+voteForm.deadline+'</span></div>'+
                           '<div  class="maxSelectNumber" style="color:transparent">'+voteForm.numberOfOptions+'</div>'+

                            '<script>'+
                              ' let endTime = new Date(document.getElementsByClassName("time")[0].innerText).getTime();'+
                              ' let NowTime = new Date().getTime();'+
                              ' if(NowTime > endTime){'+
                              '     document.getElementsByClassName("vote-container")[0].style.display = "none";'+
                              ' }'+
                              'let selectVal = document.getElementsByName("fruit")[0].id; '+
                              'let multipleSelectVal = []; '+
                              'let maxNumber = Number(document.getElementsByClassName("maxSelectNumber")[0].innerText) || 0;'+

                              'function selectChange(val) { '+
                                  'var multipleVal = document.getElementsByName("fruit");'+
                                  '  selectVal = val.value;'+
                                  '  let num = 0;'+
                                   'if(maxNumber > 0){'+
                                  '  for (let i = 0; i < multipleVal.length; i++){'+
                                  '    if (multipleVal[i].checked == true){'+
                                  '        num += 1'+
                                  '    }'+
                                  '  }'+
                                  '  if(num > maxNumber){'+
                                    'document.getElementsByClassName("msg")[0].innerText = "提示：多选个数最多为"+maxNumber+"个";' +
                                    'document.getElementsByClassName("msg")[0].style.color = "red";' +
                                     ' val.checked = false;'+
                                    '  setTimeout(() => {'+
                                     '    document.getElementsByClassName("msg")[0].style.color = "transparent"; '+
                                     '}, 2000);'+
                                  '  }'+
                                  '}'+
                               '}'+

                               'function vote() {'+
                               '    var multipleVal = document.getElementsByName("fruit"); '+
                               '    multipleSelectVal = []; '+
                               '    for (let i = 0; i < multipleVal.length; i++) {'+
                               '        if (multipleVal[i].checked == true) {'+
                               '            multipleSelectVal.push(multipleVal[i].id)'+
                               '        }'+
                               '    } '+
                               '    let selectType = document.getElementsByClassName("title")[0].innerText.indexOf("单选") != -1;'+
                               '    if(selectType){'+
                               '        console.log(selectVal);'+
                               '    }else{'+
                                'if(multipleSelectVal.length < 2){'+
                                 '      document.getElementsByClassName("msg")[0].innerText = "提示：多选个数需大于1"; '+
                                 '      document.getElementsByClassName("msg")[0].style.color = "red"; '+
                                 '       setTimeout(() => {'+
                                 '          document.getElementsByClassName("msg")[0].style.color = "transparent"; '+
                                 '       }, 2000);  '+
                                 '  }'+
                               '    }'+

                               '}'+
                            '</script>'+
                            '</div>'+
                            '<br>'


  RE.insertHTML(html);
}

RE.insertImage = function(url,viewId) {
//    var html = '<img src="' + url + '" alt="' + alt + '" />';

    var html = '</br><div style="position: relative;" class="'+ viewId + '" >'
      +'<div style="position: absolute;right: 0;top: 0;margin-top: 10px;margin-right: 10px;border-radius: 50%;width: 18px;height: 18px;text-align: center;" >'
      +'<img src="https://yty.obs.cn-south-1.myhuaweicloud.com/move/5bb4dd8190af4806b38f1522de5fc24f.png" alt="" width="100%" srcset="" onclick="delImg('+viewId+')">'
      +'</div>'
      +'<img src="' + url + '" style="width: 100%;border-radius:4px" alt="" ></div></br>';

    RE.insertHTML(html);
}

function delImg(viewId) {
    let picture = document.getElementsByClassName(viewId)[0]
    picture.parentNode.removeChild(picture);
}

RE.insertImageW = function(url, width) {
    var html = '<img src="' + url + '" alt="' + alt + '" width="' + width + '"/>';
    RE.insertHTML(html);
}

RE.insertImageWH = function(url, alt, width, height) {
    var html = '<img src="' + url + '" alt="' + alt + '" width="' + width + '" height="' + height +'"/>';
    RE.insertHTML(html);
}

RE.insertVideo = function(url, viewId) {
    var html = '<video src="' + url + '" controls></video><br>';
    RE.insertHTML(html);
}

RE.insertVideoW = function(url,viewId,width) {
//  var html = '<video src="' + url + '" width="' + width + '" controls></video><br>';
    var html = '</br><div style="position:relative;" class="'+ viewId + '">'
    + '<video src="'+ url +'#t=0.5" playsinline controls controlslist="nodownload nofullscreen noremoteplayback noplaybackrate" disablePictureInPicture x5-video-player-type="h5" x5-video-player-fullscreen="true" id="'+viewId+'" onplay="isPlay('+viewId+')" onpause="isPause('+viewId+')"  preload="metadata" style="max-height:300px;width:100%;border-radius:4px;"><source src="'+ url +'#t=0.5" type="video/mp4"></video>'
    + '<img src="https://yty.obs.cn-south-1.myhuaweicloud.com/move/d96391099cff43e2b24ae2eadb9a9b3e.png" style="width: 50px;height:50px;position: absolute;top: 50%;margin-top: -25px;left: 50%;margin-left: -25px;" class="playBtn-'+viewId+'" onclick="isPlay('+viewId+')"  alt="">'
    + '<img src="https://yty.obs.cn-south-1.myhuaweicloud.com/move/5303332bc2134aef8153477d4e395ce3.png" style="width: 50px;height:50px;position: absolute;top: 50%;margin-top: -25px;left: 50%;margin-left: -25px;display:none;" class="pauseBtn-'+viewId+'" onclick="isPlay('+viewId+')"  alt="">'
    + '<div style="background-color:transparent;width:100%;height: 100%;position: absolute;top:0;left: 0;display: none;" class="videoMask-'+viewId+'" onClick="clickPause('+viewId+')"></div>'
    + '<div style="position: absolute;right: 0;top: 0;margin-top: 10px;margin-right: 10px;border-radius: 50%;width: 18px;height: 18px;text-align: center;" >'
    + '<img src="https://yty.obs.cn-south-1.myhuaweicloud.com/move/5bb4dd8190af4806b38f1522de5fc24f.png" alt="" width="100%" srcset="" onclick="delVideo('+viewId+')">'
    + '<script>'
    + 'function isPlay(viewId){'
    + '   let playBtn = document.getElementsByClassName("playBtn-" + viewId)[0]'
    + '   let pauseBtn = document.getElementsByClassName("pauseBtn-"+ viewId)[0]'
    + '   let video = document.getElementById(viewId)'
    + '   video.play()'
    + '   playBtn.style.display="none"'
    + '   pauseBtn.style.display="none"'

    + '   let videoMask = document.getElementsByClassName("videoMask-"+viewId)[0]'
    + '   videoMask.style.display="block"'
    + '}'

    + 'function isPause(viewId) {'
    + '    let playBtn = document.getElementsByClassName("playBtn-" + viewId)[0]'
    + '    let pauseBtn = document.getElementsByClassName("pauseBtn-" + viewId)[0]'
    + '    playBtn.style.display="none"'
    + '   pauseBtn.style.display="block"'
    + '}'

    + ' function clickPause(viewId) {'
    + '   let playBtn = document.getElementsByClassName("playBtn-" + viewId)[0]'
    + '   let pauseBtn = document.getElementsByClassName("pauseBtn-"+ viewId)[0]'
    + '   let videoMask = document.getElementsByClassName("videoMask-"+viewId)[0]'
    + '   let video = document.getElementById((viewId))'

    + '  if(document.getElementsByClassName("pauseBtn-"+ viewId)[0].style.display == "none"){'
    + '    videoMask.style.display="block"'
    + '    pauseBtn.style.display="block"'
    + '    playBtn.style.display="none"'
    + '   video.pause()'
    + '  } else {'
    + '    videoMask.style.display="none"'
    + '    pauseBtn.style.display="none"'
    + '   video.play()'
    + '  }'
    + '}'
    + '</script>'
    + '</div>'
    +'</br>';

 RE.insertHTML(html);
}

function isPlay(viewId){
   let playBtn = document.getElementsByClassName("playBtn-" + viewId)[0]
   let pauseBtn = document.getElementsByClassName("pauseBtn-"+ viewId)[0]
   let video = document.getElementById(viewId)
   video.play()
   playBtn.style.display="none"
   pauseBtn.style.display="none"

   let videoMask = document.getElementsByClassName("videoMask-"+viewId)[0]
   videoMask.style.display="block"
}

function isPause(viewId) {
    let playBtn = document.getElementsByClassName("playBtn-" + viewId)[0]
    let pauseBtn = document.getElementsByClassName("pauseBtn-" + viewId)[0]
    playBtn.style.display="none"
    pauseBtn.style.display="block"
}

 function clickPause(viewId) {
   let playBtn = document.getElementsByClassName("playBtn-" + viewId)[0]
   let pauseBtn = document.getElementsByClassName('pauseBtn-'+ viewId)[0]
   let videoMask = document.getElementsByClassName("videoMask-"+viewId)[0]
   let video = document.getElementById((viewId))

  if(document.getElementsByClassName('pauseBtn-'+ viewId)[0].style.display == 'none'){
    videoMask.style.display="block"
    pauseBtn.style.display="block"
    playBtn.style.display="none"
    video.pause()
  } else {
    videoMask.style.display="none"
    pauseBtn.style.display="none"
    video.play()
  }
}

function delVideo(viewId) {
    let video = document.getElementsByClassName(viewId)[0]
    video.parentNode.removeChild(video);
}

RE.insertVideoWH = function(url, width, height) {
    var html = '<video src="' + url + '" width="' + width + '" height="' + height + '" controls></video><br>';
    RE.insertHTML(html);
}

RE.insertAudio = function(url, alt) {
    var html = '<audio src="' + url + '" controls></audio><br>';
    RE.insertHTML(html);
}

RE.insertYoutubeVideo = function(url) {
    var html = '<iframe width="100%" height="100%" src="' + url + '" frameborder="0" allow="accelerometer; autoplay; clipboard-write; encrypted-media; gyroscope; picture-in-picture" allowfullscreen></iframe><br>'
    RE.insertHTML(html);
}

RE.insertYoutubeVideoW = function(url, width) {
    var html = '<iframe width="' + width + '" src="' + url + '" frameborder="0" allow="accelerometer; autoplay; clipboard-write; encrypted-media; gyroscope; picture-in-picture" allowfullscreen></iframe><br>'
    RE.insertHTML(html);
}

RE.insertYoutubeVideoWH = function(url, width, height) {
    var html = '<iframe width="' + width + '" height="' + height + '" src="' + url + '" frameborder="0" allow="accelerometer; autoplay; clipboard-write; encrypted-media; gyroscope; picture-in-picture" allowfullscreen></iframe><br>'
    RE.insertHTML(html);
}

RE.insertEmoji = function(emoji) {
    var html = '<span>'+ emoji + '</span>';
    RE.insertHTML(html);
}

//插入分割线
RE.insertHr = function() {
    var html = '</br></br><hr color=#e2e2e2 size=1 /></br></br>';
    RE.insertHTML(html);
}

RE.insertHTML = function(html) {
    RE.restorerange();
    document.execCommand('insertHTML', false, html);
}

RE.insertLink = function(url, title) {
    RE.restorerange();
    var sel = document.getSelection();
    if (sel.toString().length == 0) {
        document.execCommand("insertHTML",false,"<a href='"+url+"'>"+title+"</a>");
    } else if (sel.rangeCount) {
       var el = document.createElement("a");
       el.setAttribute("href", url);
       el.setAttribute("title", title);

       var range = sel.getRangeAt(0).cloneRange();
       range.surroundContents(el);
       sel.removeAllRanges();
       sel.addRange(range);
   }
    RE.callback();
}

RE.setTodo = function(text) {
    var html = '<input type="checkbox" name="'+ text +'" value="'+ text +'"/> &nbsp;';
    document.execCommand('insertHTML', false, html);
}

RE.prepareInsert = function() {
    RE.backuprange();
}

RE.backuprange = function(){
    var selection = window.getSelection();
    if (selection.rangeCount > 0) {
      var range = selection.getRangeAt(0);
      RE.currentSelection = {
          "startContainer": range.startContainer,
          "startOffset": range.startOffset,
          "endContainer": range.endContainer,
          "endOffset": range.endOffset};
    }
}

RE.restorerange = function(){
    var selection = window.getSelection();
    selection.removeAllRanges();
    var range = document.createRange();
    range.setStart(RE.currentSelection.startContainer, RE.currentSelection.startOffset);
    range.setEnd(RE.currentSelection.endContainer, RE.currentSelection.endOffset);
    selection.addRange(range);
}

RE.enabledEditingItems = function(e) {
    var items = [];
    if (document.queryCommandState('bold')) {
        items.push('bold');
    }
    if (document.queryCommandState('italic')) {
        items.push('italic');
    }
    if (document.queryCommandState('subscript')) {
        items.push('subscript');
    }
    if (document.queryCommandState('superscript')) {
        items.push('superscript');
    }
    if (document.queryCommandState('strikeThrough')) {
        items.push('strikeThrough');
    }
    if (document.queryCommandState('underline')) {
        items.push('underline');
    }
    if (document.queryCommandState('insertOrderedList')) {
        items.push('orderedList');
    }
    if (document.queryCommandState('insertUnorderedList')) {
        items.push('unorderedList');
    }
    if (document.queryCommandState('justifyCenter')) {
        items.push('justifyCenter');
    }
    if (document.queryCommandState('justifyFull')) {
        items.push('justifyFull');
    }
    if (document.queryCommandState('justifyLeft')) {
        items.push('justifyLeft');
    }
    if (document.queryCommandState('justifyRight')) {
        items.push('justifyRight');
    }
    if (document.queryCommandState('insertHorizontalRule')) {
        items.push('horizontalRule');
    }
    var formatBlock = document.queryCommandValue('formatBlock');
    if (formatBlock.length > 0) {
        items.push(formatBlock);
    }

    window.location.href = "re-state://" + encodeURI(items.join(','));
}

RE.focus = function() {
    var range = document.createRange();
    range.selectNodeContents(RE.editor);
    range.collapse(false);
    var selection = window.getSelection();
    selection.removeAllRanges();
    selection.addRange(range);
    RE.editor.focus();
}

RE.blurFocus = function() {
    RE.editor.blur();
}

RE.removeFormat = function() {
    document.execCommand('removeFormat', false, null);
}

// Event Listeners
RE.editor.addEventListener("input", RE.callback);
RE.editor.addEventListener("keyup", function(e) {
    var KEY_LEFT = 37, KEY_RIGHT = 39;
    if (e.which == KEY_LEFT || e.which == KEY_RIGHT) {
        RE.enabledEditingItems(e);
    }
});
RE.editor.addEventListener("click", RE.enabledEditingItems);
