/**
 * Copyright (C) 2020 Wasabeef
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

/**
 * See about document.execCommand: https://developer.mozilla.org/en-US/docs/Web/API/Document/execCommand
 */

var RE = {};

RE.currentSelection = {
    "startContainer": 0,
    "startOffset": 0,
    "endContainer": 0,
    "endOffset": 0};

RE.editor = document.getElementById('editor');

document.addEventListener("selectionchange", function() { RE.backuprange(); });

// Initializations
RE.callback = function() {
    window.location.href = "re-callback://" + encodeURIComponent(RE.getHtml());
}

RE.setHtml = function(contents) {
    RE.editor.innerHTML = decodeURIComponent(contents.replace(/\+/g, '%20'));
}

RE.getHtml = function() {
    return RE.editor.innerHTML;
}

RE.getText = function() {
    alert(RE.editor.innerText)
    return RE.editor.innerText;
}

RE.setBaseTextColor = function(color) {
    RE.editor.style.color  = color;
}

RE.setBaseFontSize = function(size) {
    RE.editor.style.fontSize = size;
}

RE.setPadding = function(left, top, right, bottom) {
  RE.editor.style.paddingLeft = left;
  RE.editor.style.paddingTop = top;
  RE.editor.style.paddingRight = right;
  RE.editor.style.paddingBottom = bottom;
}

RE.setBackgroundColor = function(color) {
    document.body.style.backgroundColor = color;
}

RE.setBackgroundImage = function(image) {
    RE.editor.style.backgroundImage = image;
}

RE.setWidth = function(size) {
    RE.editor.style.minWidth = size;
}

RE.setHeight = function(size) {
    RE.editor.style.height = size;
}

RE.setTextAlign = function(align) {
    RE.editor.style.textAlign = align;
}

RE.setVerticalAlign = function(align) {
    RE.editor.style.verticalAlign = align;
}

RE.setPlaceholder = function(placeholder) {
    RE.editor.setAttribute("placeholder", placeholder);
}

RE.setInputEnabled = function(inputEnabled) {
    RE.editor.contentEditable = String(inputEnabled);
}

RE.undo = function() {
    document.execCommand('undo', false, null);
}

RE.redo = function() {
    document.execCommand('redo', false, null);
}

RE.setBold = function() {
    document.execCommand('bold', false, null);
}

RE.setItalic = function() {
    document.execCommand('italic', false, null);
}

RE.setSubscript = function() {
    document.execCommand('subscript', false, null);
}

RE.setSuperscript = function() {
    document.execCommand('superscript', false, null);
}

RE.setStrikeThrough = function() {
    document.execCommand('strikeThrough', false, null);
}

RE.setUnderline = function() {
    document.execCommand('underline', false, null);
}

RE.setBullets = function() {
    document.execCommand('insertUnorderedList', false, null);
}

RE.setNumbers = function() {
    document.execCommand('insertOrderedList', false, null);
}

RE.setTextColor = function(color) {
    RE.restorerange();
//    var html = '<span style="color:'+color+'"></span>';
//    RE.insertHTML(html);
    document.execCommand("styleWithCSS", null, true);
    document.execCommand('foreColor', false, color);
    document.execCommand("styleWithCSS", null, false);
}

RE.setTextBackgroundColor = function(color) {
    RE.restorerange();
    document.execCommand("styleWithCSS", null, true);
    document.execCommand('hiliteColor', false, color);
    document.execCommand("styleWithCSS", null, false);
}

RE.setFontSize = function(fontSize){
    document.execCommand("fontSize", false, fontSize);
}

RE.setHeading = function(heading) {
    document.execCommand('formatBlock', false, '<h'+heading+'>');
}

RE.setIndent = function() {
    document.execCommand('indent', false, null);
}

RE.setOutdent = function() {
    document.execCommand('outdent', false, null);
}

RE.setJustifyLeft = function() {
    document.execCommand('justifyLeft', false, null);
}

RE.setJustifyCenter = function() {
    document.execCommand('justifyCenter', false, null);
}

RE.setJustifyRight = function() {
    document.execCommand('justifyRight', false, null);
}

RE.setBlockquote = function() {
    document.execCommand('formatBlock', false, '<blockquote>');
//    if(b)
//    document.execCommand('formatBlock', false, '<blockquote>');
//    else
//    document.execCommand('formatBlock', false, '<p>');
}

RE.insertShareVoteLink = function(title,postsId) {
  var html =  ' <div class="voteLinkBtn"  contenteditable="false" style="background: #ececec;border-radius: 4px;display: flex;align-items: center;font-size: 12px;padding: 10px 20px;" onclick="voteLink('+postsId+')">'+
              '   <div style="color:#FFF;width: 36px;height: 36px;text-align: center;line-height: 36px;background-color: #0eb6ff;border-radius: 4px;">投票</div>'+
              '   <div style="margin-left:10px">'+title+'</div>'+
              '</div></br></br>'+
              '<script>'+
              '    function voteLink(id) { '+
              '     document.getElementsByClassName("voteLinkBtn")[0].style.opacity = "0.8";'+
              '        setTimeout(() => {'+
              '           document.getElementsByClassName("voteLinkBtn")[0].style.opacity = "1";'+
              '        }, 100);'+
              '     window.android.voteLink(id);'+
              '   }'+
              '</script>'
   RE.insertHTML(html);
}

RE.insertShareVoteText = function(startText,endText,userId,userName) {
   var html = '<div >' +
        '     <span >'+startText+'</span>'+
//        '     <a href="javascript:void:(0)" style="text-decoration: none;color: #0EB6FF;" onclick="atUserName('+userId+')>'+userName+'</a>'+
        '     <span class="atUser-text" style="color:#409de6" onclick="atUserName('+userId+')">'+userName+'</span>'+
        '     <span >'+endText+'</span>'+
        '</div></br></br>'+
        '<script>'+
        '    function atUserName(id) { '+
        '      document.getElementsByClassName("atUser-text")[0].style.color ="#42c4ff";'+
        '        setTimeout(() => {'+
        '           document.getElementsByClassName("atUser-text")[0].style.color ="#409de6";'+
        '        }, 100);'+
        '      window.android.atUserName(id);'+
        '   }'+
        '</script>'
   RE.insertHTML(html);
}

// com.niukou.tengyun.community.ui.state.publish.PublishArticleViewModel.getPostOverView 中有使用这些className
RE.insertVote = function(voteInfo,voteFormObj,viewId) {

  let voteForm = JSON.parse(voteInfo)
  let selectItem = ""
  let resultItem = ""

  if(voteForm.imageVoteOptionList == undefined){
  // 文字投票
      if(voteForm.numberOfOptions == 1){
         // 单选
         for (let i = 0; i < voteForm.textVoteOptionList.length; i++) {
            selectItem += '<label style="display:block;display: flex;align-items: center;justify-content: space-between;background-color: #fff;padding:10px 20px;border-radius: 16px;margin-top: 6px;" for="'+ i +'"><span>'+ voteForm.textVoteOptionList[i].option +'</span><input type="radio" style="margin:0" id="'+ i +'" name ="voteItem" value="'+ i +'"></label>'
            resultItem += '  <div class="proportion" style=" position: relative; display: flex; padding: 10px 20px; background-color: #fff; border-radius: 16px; margin-top: 10px; justify-content: space-between;">'+
               '     <div class="proportion-left" style="z-index: 999">'+
               '      <span class="optionText"></span>'+
               '      <span style="color: #429ce3" class="percentage">0%</span>'+
               '     </div>'+
               '     <div class="voteTotalNumber" style="z-index: 999">0</div>'+
               '     <div class="progress-bar" style=" background-color: #c7e8ff; position: absolute; top: 0; left: 0; width: 0%; height: 100%; border-top-left-radius: 16px; border-bottom-left-radius: 16px;"></div>'+
               '    </div>'
         }
      }else{
      // 多选
        for (let i = 0; i < voteForm.textVoteOptionList.length; i++) {
            selectItem += '<label style="display:block;display: flex;align-items: center;justify-content: space-between;background-color: #fff;padding:10px 20px;border-radius: 16px;margin-top: 6px;" for="'+ i +'"><span>'+ voteForm.textVoteOptionList[i].option +'</span><input type="checkbox" style="margin:0" id="'+ i +'" name ="voteItem" value="'+ i +'"></label>'  
            resultItem += '  <div class="proportion" style=" position: relative; display: flex; padding: 10px 20px; background-color: #fff; border-radius: 16px; margin-top: 10px; justify-content: space-between;">'+
               '     <div class="proportion-left" style="z-index: 999">'+
               '      <span class="optionText"></span>'+
               '      <span style="color: #429ce3" class="percentage">0%</span>'+
               '     </div>'+
               '     <div class="voteTotalNumber" style="z-index: 999">0</div>'+
               '     <div class="progress-bar" style=" background-color: #c7e8ff; position: absolute; top: 0; left: 0; width: 0%; height: 100%; border-top-left-radius: 16px; border-bottom-left-radius: 16px;"></div>'+
               '    </div>'
         }
      }
  } else {
    // 图片投票
        if(voteForm.numberOfOptions == 1){
           // 单选
            for (let i = 0; i < voteForm.imageVoteOptionList.length; i++) {               
                selectItem += '<label style="display:block;display: flex;align-items: center;justify-content: space-between;background-color: #fff;padding:10px;border-radius: 16px;margin-top: 6px;" for="'+voteForm.imageVoteOptionList[i].option+'"><div style="display: flex;align-items: center;"><img class="optionImg" src="'+voteForm.imageVoteOptionList[i].pictureUrl+'" style="width: 50px;height: 50px;margin-right:10px;" alt=""><span>'+voteForm.imageVoteOptionList[i].option+'</span></div><input type="radio" style="margin:0" id="'+voteForm.imageVoteOptionList[i].option+'" name ="voteItem" value="'+voteForm.imageVoteOptionList[i].option+'" onclick="selectChange('+voteForm.imageVoteOptionList[i].option+')"></label>' 
                resultItem += '  <div class="proportion" style=" position: relative; display: flex; padding: 10px; background-color: #fff; border-radius: 16px; margin-top: 10px;padding-right: 20px; justify-content: space-between;align-items: center;">'+
               '     <div class="proportion-left" style="z-index: 999;display: flex;align-items: center;">'+
               '     <img class="result-optionImg" src="" style="width: 50px;height: 50px;margin-right:10px;" alt="">'+
               '      <span class="optionText"></span>'+
               '      <span style="color: #429ce3; padding-left: 10px;" class="percentage">0%</span>'+
               '     </div>'+
               '     <div class="voteTotalNumber" style="z-index: 999">0</div>'+
               '     <div class="progress-bar" style=" background-color: #c7e8ff; position: absolute; top: 0; left: 0; width: 0%; height: 100%; border-top-left-radius: 16px; border-bottom-left-radius: 16px;"></div>'+
               '    </div>'
            }
        }else{
        // 多选
           for (let i = 0; i < voteForm.imageVoteOptionList.length; i++) {
               selectItem += '<label style="display:block;display: flex;align-items: center;justify-content: space-between;background-color: #fff;padding:10px;border-radius: 16px;margin-top: 6px;" for="' + voteForm.imageVoteOptionList[i].option + '"><div style="display: flex;align-items: center;"><img class="optionImg" src="' + voteForm.imageVoteOptionList[i].pictureUrl + '" style="width: 50px;height: 50px;margin-right:20px;" alt=""><span>' + voteForm.imageVoteOptionList[i].option + '</span></div><input type="checkbox" style="margin:0" id="' + voteForm.imageVoteOptionList[i].option + '" name ="voteItem" value="' + voteForm.imageVoteOptionList[i].option + '" onclick="selectChange(' + voteForm.imageVoteOptionList[i].option + ')"></label>'
               resultItem += '  <div class="proportion" style=" position: relative; display: flex; padding: 10px; background-color: #fff; border-radius: 16px; margin-top: 10px;padding-right: 20px; justify-content: space-between;align-items: center;">'+
               '     <div class="proportion-left" style="z-index: 999;display: flex;align-items: center;">'+
               '        <img class="result-optionImg" src="" style="width: 50px;height: 50px;margin-right:10px;" alt="">'+
               '        <span class="optionText"></span>'+
               '        <span style="color: #429ce3;padding-left: 10px;" class="percentage">0%</span>'+
               '     </div>'+
               '     <div class="voteTotalNumber" style="z-index: 999">0</div>'+
               '     <div class="progress-bar" style=" background-color: #c7e8ff; position: absolute; top: 0; left: 0; width: 0%; height: 100%; border-top-left-radius: 16px; border-bottom-left-radius: 16px;"></div>'+
               '    </div>'
             }
        }
  }

  var html = '</br>'+
   '<div id="vote-baseview-'+viewId+'" class="vote-baseview" style="margin: 11px;-webkit-user-modify: read-only;-webkit-user-select:none;">'+
   '<div contenteditable="false" class="vote-overview" style="font-size: 14px;position: relative;background-color: #f8f8f8;padding: 10px;border-radius: 8px;width: 90%;-webkit-user-modify: read-only;">'+
                        '<div id="vote-overview-delete-btn" onclick="delVote('+viewId+')" style="width:20px;height:20px;display:flex;border-radius: 50%;background-color:#b3b3b3;color: #fcfcfc;align-items: center;justify-content: center;right: -8px;top: -10px;position: absolute;">'+
                           '<svg t="1669451861074" class="icon" viewBox="0 0 1024 1024" version="1.1" xmlns="http://www.w3.org/2000/svg" p-id="3496" width="12" height="12"><path d="M584.127 514.61L910.316 840.8c20.01 20.01 20.082 52.467 0 72.549-20.011 20.011-52.468 20.082-72.55 0L511.579 587.16 185.39 913.348c-20.011 20.011-52.467 20.082-72.55 0-20.01-20.011-20.081-52.467 0-72.55L439.1 514.54 112.91 188.35c-20.01-20.01-20.081-52.467 0-72.549 20.012-20.01 52.468-20.082 72.55 0l326.188 326.189 326.188-326.189c20.011-20.01 52.468-20.082 72.55 0 20.01 20.011 20.081 52.468 0 72.55L584.126 514.61z" fill="#ffffff" p-id="3497"></path></svg>'+
                        '</div>'+
                        '<div style="display: flex;align-items: center;">'+
                             '<img class="vote-overview-img" style="width: 60px;height: 60px;" src="https://yty.obs.cn-south-1.myhuaweicloud.com/move/710d5f481fae489c9891d745cfe9ddd8.png" alt="">'+
                             '<span style="font-size: 14px; overflow: hidden;display:-webkit-box;-webkit-line-clamp: 2;-webkit-box-orient: vertical;text-overflow: ellipsis;padding-left: 10px;line-height: 20px;">'+voteForm.title+'</span>'+
                        '</div>'+
   '</div>'+
  '<div id="vote-form-'+viewId+'"  class="vote-container" style="font-size: 14px;display:none;background-color: #ececec;padding:20px;margin-top: 10px ;margin-bottom: 10px ;padding-bottom:1px;border-radius: 6px;font-size: 14px;position:relative;">'+
                            '     <div  style="margin-bottom:10px" class="title">'+voteForm.title+'（'+voteForm.numberOfOptionsText+'）</div>'+

                          '<div>'+
                            '<div class="voteForm">'+ selectItem +
                            '<div class="voteBtn" style="background-color: #409de6;color: #fff;padding: 10px 0;border-radius: 20px;text-align: center;margin-top: 10px;">投票</div>'+
                            '</div>'+
                            ' <div style="display:none" class="resultForm">'+
                                                 resultItem +
                                                 ' <div class="share-btn" style=" background-color: #409de6; color: #fff; padding: 10px 0; border-radius: 20px; text-align: center; margin-top: 10px;">'+
                                                 '  <span class="numberOfParticipants" style="padding-right:10px;"></span>'+
                                                 '  <span class="share-text"  >分享我的投票与观点</span>'+
                                                 '</div>'+
                            ' </div>'+
                            '</div>'+

                           '<div class="deadline-time" style="margin-top:10px; text-align: center; color:#9a999a; font-size:12px;" >投票截止时间：<span class="time">'+voteForm.deadline+'</span></div>'+
                           '<div  class="maxSelectNumber" style="color:transparent">'+voteForm.numberOfOptions+'</div>'+
                            '</div>'+
                            '</div>'+
                            '</div>'+
                            '<br>'


  RE.insertHTML(html);
}

function delVote(viewId) {
   let vote = document.getElementById(`vote-baseview-${viewId}`)
   vote.parentNode.removeChild(vote);
   console.log("del vote "+viewId)
   window.android.delVote(viewId)
   RE.callback();
}

// com.niukou.tengyun.community.ui.state.publish.PublishArticleViewModel.getPostOverView 中有使用这些className
RE.insertImage = function(url,viewId) {
//    var html = '<img src="' + url + '" alt="' + alt + '" />';
    var html = '</br><div style="position: relative;" class="'+ viewId + '" >'
      +'<div style="position: absolute;right: 0;top: 0;margin-top: 10px;margin-right: 10px;border-radius: 50%;width: 18px;height: 18px;text-align: center;" >'
      +'<div class="delBtn" onclick="delImg('+viewId+')" style="width:30px;height: 30px;display:flex;align-items:center;justify-content:center;border-radius: 50%;cursor: pointer;background-color: rgba(0, 0, 0, 0.5);position: absolute;top: -5px;right: -10px;"><svg t="1669451861074" class="icon" viewBox="0 0 1024 1024" version="1.1" xmlns="http://www.w3.org/2000/svg" p-id="3496" width="12" height="12"><path d="M584.127 514.61L910.316 840.8c20.01 20.01 20.082 52.467 0 72.549-20.011 20.011-52.468 20.082-72.55 0L511.579 587.16 185.39 913.348c-20.011 20.011-52.467 20.082-72.55 0-20.01-20.011-20.081-52.467 0-72.55L439.1 514.54 112.91 188.35c-20.01-20.01-20.081-52.467 0-72.549 20.012-20.01 52.468-20.082 72.55 0l326.188 326.189 326.188-326.189c20.011-20.01 52.468-20.082 72.55 0 20.01 20.011 20.081 52.468 0 72.55L584.126 514.61z" fill="#ffffff" p-id="3497"></path></svg></div>'
//      +'<img src="https://yty.obs.cn-south-1.myhuaweicloud.com/move/5bb4dd8190af4806b38f1522de5fc24f.png" alt="" class="delBtn" width="100%" srcset="" onclick="delImg('+viewId+')">'
      +'</div>'
      +'<img class="rich_picture_item" id="'+ viewId + '-img" src="' + url + '" style="width:100%;border-radius:4px" alt="" ></div></br>';

    RE.insertHTML(html);
}

RE.queryRichPictureItems = function queryRichPictureItems(){
      let imgList = []
      let imgs = document.getElementsByClassName('rich_picture_item')
      for (let i = 0; i < imgs.length; i++) {
        imgList.push(imgs[i].getAttribute("src"))
      }
      return imgList
}

function delImg(viewId) {
    let picture = document.getElementsByClassName(viewId)[0]
    picture.parentNode.removeChild(picture);
    RE.callback()
    window.android.delImg(viewId)
}

RE.insertImageW = function(url, width) {
    var html = '<img src="' + url + '" alt="' + alt + '" width="' + width + '"/>';
    RE.insertHTML(html);
}

RE.insertImageWH = function(url, alt, width, height) {
    var html = '<img src="' + url + '" alt="' + alt + '" width="' + width + '" height="' + height +'"/>';
    RE.insertHTML(html);
}

// 新视频H5,待调试_发布文章-插入视频最新
//// com.niukou.tengyun.community.ui.state.publish.PublishArticleViewModel.getPostOverView 中有使用这些className
RE.insertSuccessVideo2 = function(data){
    //videoId,videoUrl,videoIcon,duration
    let res = JSON.parse(data)
    //竖屏视频要加入这个style,保证视频封面居中显示,横屏视频不需要
    var bgPositionY = res.isVertical?'background-position-y: 50%;':''

    var html = '<br><div video-url="'+ res.videoUrl +'" video-cover="'+ res.videoIcon +'" class="real-video-f-div" id="'+res.videoId+'-video" style="'+bgPositionY+'background-image: url('+ res.videoIcon +');width: 100%;min-width: 100px;max-width: 100%;height: 200px;background-size: cover;font-size: 12px;position: relative;color: #fff;display: flex;align-items: center;justify-content: center;-webkit-user-modify: read-only;-webkit-user-select:none;background-repeat: no-repeat;background-color: #000">'+
    '<div id="'+res.videoId+'-delVideoImg" class="del-btn" style="font-size: 18px;position: absolute;top: 9px;right: 9px;background-color: rgba(0, 0, 0, 0.3);width: 20px;height: 20px;border-radius: 50%;text-align: center;line-height: 20px;">×</div>'+
    '<img class="buttonImg" src="https://yty.obs.cn-south-1.myhuaweicloud.com/move/ce109f4739ef440ab115e20fdf562f2c.png" alt="" style="user-select: none;width: 42px;height: 42px;">'+
    '<div style="background-color: rgba(0, 0, 0, 0.3);border-radius: 10px;position: absolute;right: 5px;bottom: 5px;padding: 2px 4px;">'+ res.duration +'</div>'+
     '</div>'+'<br>';
    
    RE.insertHTML(html);
//    var flag = false;
    $("#"+res.videoId+"-delVideoImg").on("touchend",function(event){
            this.parentNode.parentNode.removeChild(this.parentNode);
            RE.callback();
            window.android.delVideo(res.videoId)
//         该方法将停止事件的传播,阻止它被分派到其他 Document 节点
         event.stopPropagation();
     });

}

RE.insertVideo = function(url, viewId) {
    var html = '<video src="' + url + '" controls></video><br>';
    RE.insertHTML(html);
}

RE.insertVideoW = function(url,coverUrl,viewId,width) {
//  var html = '<video src="' + url + '" width="' + width + '" controls></video><br>';
    var html = '</br><div style="position:relative;width:100%" class="'+ viewId + '">'
    + '<video class="rich_video_item"  src="'+ url +'#t=0.5" playsinline controls controlslist="nodownload nofullscreen noremoteplayback noplaybackrate" poster="'+coverUrl+'" disablePictureInPicture x5-video-player-type="h5" x5-video-player-fullscreen="true" id="'+viewId+'" onplay="isPlay('+viewId+')" onpause="isPause('+viewId+')"  preload="metadata" style="width:100%;border-radius:4px;object-fit: fill;"><source src="'+ url +'#t=0.5" type="video/mp4"></video>'
//    + '<img src="https://yty.obs.cn-south-1.myhuaweicloud.com/move/d96391099cff43e2b24ae2eadb9a9b3e.png" style="width: 50px;height:50px;position: absolute;top: 50%;margin-top: -25px;left: 50%;margin-left: -25px;" class="playBtn-'+viewId+' playBtn" onclick="isPlay('+viewId+')"  alt="">'
//    + '<img src="https://yty.obs.cn-south-1.myhuaweicloud.com/move/5303332bc2134aef8153477d4e395ce3.png" style="width: 50px;height:50px;position: absolute;top: 50%;margin-top: -25px;left: 50%;margin-left: -25px;display:none;" class="pauseBtn-'+viewId+' pauseBtn" onclick="isPlay('+viewId+')"  alt="">'
    + '<div style="background-color:transparent;width:100%;height: 100vh;position: absolute;top:0;left: 0;display: none;" class="videoMask-'+viewId+'" onClick="clickPause('+viewId+')"></div>'
    + '<div style="position: absolute;right: 0;top: 0;margin-top: 10px;margin-right: 10px;border-radius: 50%;width: 18px;height: 18px;text-align: center;" >'
//    + '<img class="delBtn" src="https://yty.obs.cn-south-1.myhuaweicloud.com/move/5bb4dd8190af4806b38f1522de5fc24f.png" alt="" width="100%" srcset="" onclick="delVideo('+viewId+')">'
    + '<div class="delBtn"  onclick="delVideo('+viewId+')" style="width:30px;height: 30px;display:flex;align-items:center;justify-content:center;border-radius: 50%;cursor: pointer;background-color: rgba(0, 0, 0, 0.5);position: absolute;top: -5px;right: -5px;"><svg t="1669451861074" class="icon" viewBox="0 0 1024 1024" version="1.1" xmlns="http://www.w3.org/2000/svg" p-id="3496" width="12" height="12"><path d="M584.127 514.61L910.316 840.8c20.01 20.01 20.082 52.467 0 72.549-20.011 20.011-52.468 20.082-72.55 0L511.579 587.16 185.39 913.348c-20.011 20.011-52.467 20.082-72.55 0-20.01-20.011-20.081-52.467 0-72.55L439.1 514.54 112.91 188.35c-20.01-20.01-20.081-52.467 0-72.549 20.012-20.01 52.468-20.082 72.55 0l326.188 326.189 326.188-326.189c20.011-20.01 52.468-20.082 72.55 0 20.01 20.011 20.081 52.468 0 72.55L584.126 514.61z" fill="#ffffff" p-id="3497"></path></svg></div>'
    + '</div>'
//    + '<style>'
//    + 'video::-webkit-media-controls-mute-button {display: none !important;}'
//    + 'video::-webkit-media-controls-fullscreen-button {display: none !important;}'
//    + '</style>'
    + '<script>'
    + 'function isPlay(viewId){'
    + '   let playBtn = document.getElementsByClassName("playBtn-" + viewId)[0]'
    + '   let pauseBtn = document.getElementsByClassName("pauseBtn-"+ viewId)[0]'
    + '   let video = document.getElementById(viewId)'
    + '   video.play()'
    + '   playBtn.style.display="none"'
    + '   pauseBtn.style.display="none"'

    + '   let videoMask = document.getElementsByClassName("videoMask-"+viewId)[0]'
    + '   videoMask.style.display="block"'
    + '}'

    + 'function isPause(viewId) {'
    + '    let playBtn = document.getElementsByClassName("playBtn-" + viewId)[0]'
    + '    let pauseBtn = document.getElementsByClassName("pauseBtn-" + viewId)[0]'
    + '    playBtn.style.display="none"'
    + '   pauseBtn.style.display="block"'
    + '}'

    + ' function clickPause(viewId) {'
    + '   let playBtn = document.getElementsByClassName("playBtn-" + viewId)[0]'
    + '   let pauseBtn = document.getElementsByClassName("pauseBtn-"+ viewId)[0]'
    + '   let videoMask = document.getElementsByClassName("videoMask-"+viewId)[0]'
    + '   let video = document.getElementById((viewId))'

    + '  if(document.getElementsByClassName("pauseBtn-"+ viewId)[0].style.display == "none"){'
    + '    videoMask.style.display="block"'
    + '    pauseBtn.style.display="block"'
    + '    playBtn.style.display="none"'
    + '   video.pause()'
    + '  } else {'
    + '    videoMask.style.display="none"'
    + '    pauseBtn.style.display="none"'
    + '   video.play()'
    + '  }'
    + '}'
    + '</script>'
    + '</div>'
    +'</br>';

 RE.insertHTML(html);
}

RE.delVideoByViewId = function(viewId) {
   delVideo(viewId)
}

function isPlay(viewId){
   let playBtn = document.getElementsByClassName("playBtn-" + viewId)[0]
   let pauseBtn = document.getElementsByClassName("pauseBtn-"+ viewId)[0]
   let video = document.getElementById(viewId)
   video.play()
   playBtn.style.display="none"
   pauseBtn.style.display="none"

   let videoMask = document.getElementsByClassName("videoMask-"+viewId)[0]
   videoMask.style.display="block"
}

function isPause(viewId) {
    let playBtn = document.getElementsByClassName("playBtn-" + viewId)[0]
    let pauseBtn = document.getElementsByClassName("pauseBtn-" + viewId)[0]
    playBtn.style.display="none"
    pauseBtn.style.display="block"
}

 function clickPause(viewId) {
   let playBtn = document.getElementsByClassName("playBtn-" + viewId)[0]
   let pauseBtn = document.getElementsByClassName('pauseBtn-'+ viewId)[0]
   let videoMask = document.getElementsByClassName("videoMask-"+viewId)[0]
   let video = document.getElementById((viewId))

  if(document.getElementsByClassName('pauseBtn-'+ viewId)[0].style.display == 'none'){
    videoMask.style.display="block"
    pauseBtn.style.display="block"
    playBtn.style.display="none"
    video.pause()
  } else {
    videoMask.style.display="none"
    pauseBtn.style.display="none"
    video.play()
  }
}

function delVideo(viewId) {
    let video = document.getElementsByClassName(viewId)[0]
    video.parentNode.removeChild(video);

    window.android.delVideo(viewId)
}

RE.insertVideoWH = function(url, width, height) {
    var html = '<video src="' + url + '" width="' + width + '" height="' + height + '" controls></video><br>';
    RE.insertHTML(html);
}

RE.insertAudio = function(url, alt) {
    var html = '<audio src="' + url + '" controls></audio><br>';
    RE.insertHTML(html);
}

RE.insertYoutubeVideo = function(url) {
    var html = '<iframe width="100%" height="100vh" src="' + url + '" frameborder="0" allow="accelerometer; autoplay; clipboard-write; encrypted-media; gyroscope; picture-in-picture" allowfullscreen></iframe><br>'
    RE.insertHTML(html);
}

RE.insertYoutubeVideoW = function(url, width) {
    var html = '<iframe width="' + width + '" src="' + url + '" frameborder="0" allow="accelerometer; autoplay; clipboard-write; encrypted-media; gyroscope; picture-in-picture" allowfullscreen></iframe><br>'
    RE.insertHTML(html);
}

RE.insertYoutubeVideoWH = function(url, width, height) {
    var html = '<iframe width="' + width + '" height="' + height + '" src="' + url + '" frameborder="0" allow="accelerometer; autoplay; clipboard-write; encrypted-media; gyroscope; picture-in-picture" allowfullscreen></iframe><br>'
    RE.insertHTML(html);
}

RE.insertEmoji = function(emoji) {
    var html = '<span>'+ emoji + '</span>';
    RE.insertHTML(html);
}

//插入分割线
RE.insertHr = function() {
    var html = '</br></br><hr color=#e2e2e2 size=1 /></br></br>';
    RE.insertHTML(html);
}

RE.insertHTML = function(html) {
    RE.restorerange();
    document.execCommand('insertHTML', false, html);
}

// com.niukou.tengyun.community.ui.state.publish.PublishArticleViewModel.getPostOverView 中有使用这些className
RE.insertLink = function(url, icon, title) {
    var html= `<br>
                   <div id="link-overview-id" link-overview-url=${url} class="link-overview" style="position: relative;width: 90%;margin: 11px;-webkit-user-modify: read-only;-webkit-user-select:none;">
                       <div class="del-btn" onclick="RE.delLink(this)" style="width:20px;height: 20px;display:flex;align-items:center;justify-content:center;border-radius: 50%;cursor: pointer;background-color: rgba(0, 0, 0, 0.5);position: absolute;top: -10px;right: -8px;">
                           <svg t="1669451861074" class="icon" viewBox="0 0 1024 1024" version="1.1" xmlns="http://www.w3.org/2000/svg" p-id="3496" width="12" height="12"><path d="M584.127 514.61L910.316 840.8c20.01 20.01 20.082 52.467 0 72.549-20.011 20.011-52.468 20.082-72.55 0L511.579 587.16 185.39 913.348c-20.011 20.011-52.467 20.082-72.55 0-20.01-20.011-20.081-52.467 0-72.55L439.1 514.54 112.91 188.35c-20.01-20.01-20.081-52.467 0-72.549 20.012-20.01 52.468-20.082 72.55 0l326.188 326.189 326.188-326.189c20.011-20.01 52.468-20.082 72.55 0 20.01 20.011 20.081 52.468 0 72.55L584.126 514.61z" fill="#ffffff" p-id="3497"></path></svg>
                       </div>
                       <div id="link-url-id" style="-webkit-user-modify:read-only;-webkit-user-select:none;color: rgb(38, 37, 57);display:flex;align-items:center;font-size:14px;background-color:#f8f8f8;border-radius: 4px;padding: 10px;">
                           <img style="width: 60px;height: 60px;" src="${icon == '' ? 'https://yty.obs.cn-south-1.myhuaweicloud.com/move/648220d25c7b412cb0392535f706d8e8.png' : icon}" alt="">
                           <span style="font-size: 14px; overflow: hidden;display:-webkit-box;-webkit-line-clamp: 2;-webkit-box-orient: vertical;text-overflow: ellipsis;padding-left: 10px;line-height: 20px;width: calc(100% - 70px);">${title == "" ? url : title}</span>
                        </div>
                   </div>
               <br>`
    RE.insertHTML(html);
    RE.callback();
}

RE.delLink = function deleteLink(obj){
    obj.parentNode.parentNode.removeChild(obj.parentNode);
    RE.callback();
}


RE.insertAt = function(userId,userName) {
//    var html = '<div style="display:inline-block;"><span contenteditable="false" onClick="clickAtUser('+userId+')" class="rich_at_item" rich_at_item_id="'+userId+'" style="font-size:14px;color:#6095FF;">@' + userName +'</span><span> </span></div>'+
    var html = '<div style="display:inline-block;"><span contenteditable="false" class="rich_at_item" rich_at_item_id="'+userId+'" style="font-size:14px;color:#6095FF;">@' + userName +'</span><span> </span></div>'+
//       '<script>'+
//            '    function clickAtUser(id) { '+
////            '      document.getElementsByClassName("rich_at_item")[0].style.color ="#42c4ff";'+
////            '        setTimeout(() => {'+
////            '           document.getElementsByClassName("rich_at_item")[0].style.color ="#409de6";'+
////            '        }, 100);'+
//            '      window.android.clickAtUser(id);'+
//            '   }'+
//            '</script>';
//    document.execCommand('insertHTML', false, html);
   RE.insertHTML(html);
}

RE.insertAtList = function(atList) {

        let atItems = JSON.parse(atList)

         let html = ''
         atItems.forEach(item=>{
//            html += '<div style=" display:inline-block;"><span contenteditable="false" onClick="clickAtUser('+item.userId+')" class="rich_at_item rich_at_item-'+item.userId+'" rich_at_item_id="'+item.userId+'" style="font-size:14px;color:#6095FF;">@' + item.userName +'</span></div>'
            html += '<div style=" display:inline-block;"><span contenteditable="false" class="rich_at_item rich_at_item-'+item.userId+'" rich_at_item_id="'+item.userId+'" style="font-size:14px;color:#6095FF;">@' + item.userName +'</span><span> </span></div>'
         })
//         html+=         '<script>'+
//                        '    function clickAtUser(id) { '+
////                        '      document.getElementsByClassName(rich_at_item-id)[0].style.color ="#42c4ff";'+
////                        '        setTimeout(() => {'+
////                        '           document.getElementsByClassName(rich_at_item-id)[0].style.color ="#6095FF";'+
////                        '        }, 100);'+
//                        '      window.android.clickAtUser(id);'+
//                        '   }'+
//                        '</script>';
    RE.insertHTML(html);
}

RE.getPageElement = function getPageElement() {
         let imgList = []
         let videoList = []
         let atUserList = []
         let voteList = []
         let linkList = []

         let imgs = document.getElementsByClassName('rich_picture_item')
         for (let i = 0; i < imgs.length; i++) {
           imgList.push(imgs[i].getAttribute("src"))
         }

         let videos = document.getElementsByClassName('real-video-f-div')
         for (let i = 0; i < videos.length; i++) {
            videoList.push(videos[i].getAttribute("video-url"))
         }

         let atItems = document.getElementsByClassName('rich_at_item')
         for (let i = 0; i < atItems.length; i++) {
           atUserList.push(atItems[i].getAttribute("rich_at_item_id"))
         }

         let voteItems = document.getElementsByClassName('vote-overview')
         for (let i = 0; i < voteItems.length; i++) {
            //投票信息在java代码里,这里只确定有没有这个元素
           voteList.push(i+"")
         }

         let linkItems = document.getElementsByClassName('link-overview')
         for (let i = 0; i < linkItems.length; i++) {
           linkList.push(linkItems[i].getAttribute("link-overview-url"))
         }

         return {
           imgList,
           videoList,
           atUserList,
           voteList,
           linkList
         }

       }

RE.clickAtUser = function(userId) {
    window.android.clickAtUser(userId)
}

RE.insertText = function(text) {

//    RE.restorerange();
//    var sel = document.getSelection();
//    if (sel.toString().length == 0) {
//        document.execCommand("insertHTML",false,"<a href='"+text+"'>"+text+"</a>");
//    } else if (sel.rangeCount) {
//       var el = document.createElement("a");
//       el.setAttribute("href", text);
//       el.setAttribute("title", text);
//
//       var range = sel.getRangeAt(0).cloneRange();
//       range.surroundContents(el);
//       sel.removeAllRanges();
//       sel.addRange(range);
//   }
//    RE.callback();
}

RE.setTodo = function(text) {
    var html = '<input type="checkbox" name="'+ text +'" value="'+ text +'"/> &nbsp;';
    document.execCommand('insertHTML', false, html);
}

RE.prepareInsert = function() {
    RE.backuprange();
}

RE.backuprange = function(){
    var selection = window.getSelection();
    if (selection.rangeCount > 0) {
      var range = selection.getRangeAt(0);
      RE.currentSelection = {
          "startContainer": range.startContainer,
          "startOffset": range.startOffset,
          "endContainer": range.endContainer,
          "endOffset": range.endOffset};
    }
}

RE.restorerange = function(){
    var selection = window.getSelection();
    selection.removeAllRanges();
    var range = document.createRange();
    range.setStart(RE.currentSelection.startContainer, RE.currentSelection.startOffset);
    range.setEnd(RE.currentSelection.endContainer, RE.currentSelection.endOffset);
    selection.addRange(range);
}

RE.enabledEditingItems = function(e) {
    var items = [];
    if (document.queryCommandState('bold')) {
        items.push('bold');
    }
    if (document.queryCommandState('italic')) {
        items.push('italic');
    }
    if (document.queryCommandState('subscript')) {
        items.push('subscript');
    }
    if (document.queryCommandState('superscript')) {
        items.push('superscript');
    }
    if (document.queryCommandState('strikeThrough')) {
        items.push('strikeThrough');
    }
    if (document.queryCommandState('underline')) {
        items.push('underline');
    }
    if (document.queryCommandState('insertOrderedList')) {
        items.push('orderedList');
    }
    if (document.queryCommandState('insertUnorderedList')) {
        items.push('unorderedList');
    }
    if (document.queryCommandState('justifyCenter')) {
        items.push('justifyCenter');
    }
    if (document.queryCommandState('justifyFull')) {
        items.push('justifyFull');
    }
    if (document.queryCommandState('justifyLeft')) {
        items.push('justifyLeft');
    }
    if (document.queryCommandState('justifyRight')) {
        items.push('justifyRight');
    }
    if (document.queryCommandState('insertHorizontalRule')) {
        items.push('horizontalRule');
    }
    var formatBlock = document.queryCommandValue('formatBlock');
    if (formatBlock.length > 0) {
        items.push(formatBlock);
    }

    window.location.href = "re-state://" + encodeURI(items.join(','));
}

RE.focus = function() {
    var range = document.createRange();
    range.selectNodeContents(RE.editor);
    range.collapse(false);
    var selection = window.getSelection();
    selection.removeAllRanges();
    selection.addRange(range);
    RE.editor.focus();
}

RE.blurFocus = function() {
    RE.editor.blur();
}

RE.removeFormat = function() {
    document.execCommand('removeFormat', false, null);
}

// Event Listeners
RE.editor.addEventListener("input", RE.callback);
RE.editor.addEventListener("keyup", function(e) {
    var KEY_LEFT = 37, KEY_RIGHT = 39;
    if (e.which == KEY_LEFT || e.which == KEY_RIGHT) {
        RE.enabledEditingItems(e);
    }
});
RE.editor.addEventListener("click", RE.enabledEditingItems);
